package org.netkernel.layer0.bnf;

import java.io.IOException;
import java.io.StringWriter;
import java.util.regex.Pattern;

import org.netkernel.layer0.bnf.BNFGrammarFactory.BuiltIn;

/** A regular expression nested within a grammar
 * @author Tony Butterfield
 */
public class RegexPart implements IGrammarPart
{
	private final String mRegex;
	private final int mGroupCount;
	private final BuiltIn mBuiltin;
	
	public RegexPart(BuiltIn aBuiltIn)
	{	mBuiltin=aBuiltIn;
		mRegex=mBuiltin.getRegex().pattern();
		mGroupCount=mBuiltin.getGroupCount();
	}
	
	public RegexPart(String aRegex)
	{	mGroupCount=BNFGrammarFactory.patternForString(aRegex).matcher("").groupCount();
		mRegex=aRegex;
		mBuiltin=null;
	}

	RegexPart(String aRegex, int aGroupCount)
	{	mRegex=aRegex;
		mGroupCount=aGroupCount;
		mBuiltin=null;
	}
	
	String getRegex()
	{	return mRegex;
	}
	
	int getGroupCount()
	{	return mGroupCount;
	}
	
	public void writeXML(StringWriter aSW) throws IOException
	{	if (mBuiltin==null)
		{	aSW.write("<regex>");
			aSW.write(mRegex);
			aSW.write("</regex>");
		}
		else
		{	aSW.write("<regex type='");
			aSW.write(mBuiltin.getName());
			aSW.write("'/>");
		}
	}

	public void writeRegex(StringWriter aSW, NamedGroups aGroups)
	{	aGroups.skipGroups(mGroupCount);
		aSW.write( getRegex() );
	}	

}
