package org.netkernel.layer0.bnf;

import java.io.IOException;
import java.io.StringWriter;

/** A piece of static content within a grammar
 * @author Tony Butterfield
 */
class StaticPart implements IGrammarPart
{
	private final String mContent;
	
	public StaticPart(String aContent)
	{	mContent=aContent;
	}
	
	String getContent()
	{	return mContent;
	}
	
	public void writeXML(StringWriter aSW) throws IOException
	{	aSW.write(mContent);
	}	
	
	public void writeRegex(StringWriter aSW, NamedGroups aGroups)
	{ aSW.write(regexEscape(getContent()));
	}
	
	// \, +, ., *, {, }, [, ], ?, ^, $, (, )
	public static String regexEscape(String aInput)
	{	char[] input = aInput.toCharArray();
		int length=input.length;
		char [] output = new char[length*2];
		int l=0;
		for (int i=0; i<length; i++)
		{	char c=input[i];
			switch (c)
			{	case '\\':
				case '+': 
				case '.': 
				case '*': 
				case '{': 
				case '}': 
				case '[': 
				case ']': 
				case '?': 
				case '^': 
				case '$': 
				case '(': 
				case ')':
					output[l++]='\\'; 
					output[l++]=c;
					break;
				default:
					output[l++]=c;
			}
		}
		return new String(output,0,l);
	}		
}
